@@ -209,8 +209,6 @@ ags_dssi_bridge_connectable_interface_init(AgsConnectableInterface *connectable)
 {
   ags_dssi_bridge_parent_connectable_interface = g_type_interface_peek_parent(connectable);
 
-  connectable->is_ready = NULL;
-  connectable->is_connected = NULL;
   connectable->connect = ags_dssi_bridge_connect;
   connectable->disconnect = ags_dssi_bridge_disconnect;
 }
